Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(188)

Unified Diff: chrome/browser/automation/automation_provider.h

Issue 174015: Add automation call to wait for multiple navigations. (Closed)
Patch Set: backwards compatibility, properly done Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/automation/automation_provider.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/automation/automation_provider.h
diff --git a/chrome/browser/automation/automation_provider.h b/chrome/browser/automation/automation_provider.h
index 09976532f8f372c1c3c989ae2864e42aaf74b618..da47f06c17870adb3cff3b823a3a91785b60009a 100644
--- a/chrome/browser/automation/automation_provider.h
+++ b/chrome/browser/automation/automation_provider.h
@@ -69,14 +69,15 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
void SetExpectedTabCount(size_t expected_tabs);
// Add a listener for navigation status notification. Currently only
// navigation completion is observed; when the navigation completes, the
// completed_response object is sent; if the server requires authentication,
// we instead send the auth_needed_response object. A pointer to the added
// navigation observer is returned. This object should NOT be deleted and
// should be released by calling the corresponding
// RemoveNavigationStatusListener method.
NotificationObserver* AddNavigationStatusListener(
- NavigationController* tab, IPC::Message* reply_message);
+ NavigationController* tab, IPC::Message* reply_message,
+ int number_of_navigations);
void RemoveNavigationStatusListener(NotificationObserver* obs);
@@ -198,6 +199,9 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
void GetTabURL(int handle, bool* success, GURL* url);
void HandleUnused(const IPC::Message& message, int handle);
void NavigateToURL(int handle, const GURL& url, IPC::Message* reply_message);
+ void NavigateToURLBlockUntilNavigationsComplete(int handle, const GURL& url,
+ int number_of_navigations,
+ IPC::Message* reply_message);
void NavigationAsync(int handle, const GURL& url, bool* status);
void GoBack(int handle, IPC::Message* reply_message);
void GoForward(int handle, IPC::Message* reply_message);
@@ -69,14 +69,15 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
void SetExpectedTabCount(size_t expected_tabs);
// Add a listener for navigation status notification. Currently only
- // navigation completion is observed; when the navigation completes, the
- // completed_response object is sent; if the server requires authentication,
- // we instead send the auth_needed_response object. A pointer to the added
- // navigation observer is returned. This object should NOT be deleted and
- // should be released by calling the corresponding
+ // navigation completion is observed; when the |number_of_navigations|
+ // complete, the completed_response object is sent; if the server requires
+ // authentication, we instead send the auth_needed_response object. A pointer
+ // to the added navigation observer is returned. This object should NOT be
+ // deleted and should be released by calling the corresponding
// RemoveNavigationStatusListener method.
NotificationObserver* AddNavigationStatusListener(
« no previous file with comments | « no previous file | chrome/browser/automation/automation_provider.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698